@@ -14,6 +14,8 @@ import sys
 import platform
 import hashlib
 import random
+import os
+import configparser
 
 try:
     # Py3
@@ -27,8 +29,8 @@ except ImportError:
     sys.setdefaultencoding('utf8')
     input = raw_input
 
-YDAPPKEY = "1d9b4cc7c9694745"
-YDSECKEY = "U9IEK5Qc4CMuWGvbsrwBXaeO6KO7xZwJ"
+YDAPPID = os.getenv('YDCV_YOUDAO_APPID', '')
+YDAPPSEC = os.getenv('YDCV_YOUDAO_APPSEC', '')
 
 class GlobalOptions(object):
     def __init__(self, options=None):
@@ -253,11 +255,11 @@ def lookup_word(word):
 
     salt = str(random.randint(1, 65536))
     md5 = hashlib.md5()
-    md5.update("{}{}{}{}".format(YDAPPKEY,word,salt,YDSECKEY).encode('utf-8'))
+    md5.update("{}{}{}{}".format(YDAPPID,word,salt,YDAPPSEC).encode('utf-8'))
     sign = md5.hexdigest()
     yd_api = "https://openapi.youdao.com/api?" \
             "appKey={}&q={}&from={}&to={}&salt={}&sign={}".format(
-            YDAPPKEY, quote(word), _lang_from, _lang_to, salt, sign)
+            YDAPPID, quote(word), _lang_from, _lang_to, salt, sign)
 
     try:
         data = urlopen(yd_api).read().decode("utf-8")
@@ -266,6 +268,12 @@ def lookup_word(word):
     else:
         try:
             formatted = json.loads(data)
+            err_code = formatted["errorCode"]
+            if err_code != "0":
+                print("Req: {}\n ErrorCode {}".format(yd_api, err_code))
+                print("Please refer to: http://ai.youdao.com/docs/doc-trans-api.s#p08")
+                return
+
             print_explanation(word, formatted, options)
         except ValueError:
             print("Cannot parse response data, original response: \n{}".format(data))
@@ -323,7 +331,12 @@ def arg_parse():
                         action="store",
                         choices=["zh-CHS", "ja", "EN", "ko", "fr", "ru", "pt", "es", "vi", "de", "ar", "id"],
                         default='zh-CHS',
-                        help="Translate to specific language. Default: zh-CHS for non-chinese characters, EN if Chinese character queried.")
+                        help="Translate to specific language. "
+                        "Default: zh-CHS for non-chinese characters, EN if Chinese character queried.")
+    parser.add_argument('-c', '--config',
+                        action="store",
+                        default="~/.ydcv",
+                        help="Config file contains API AppKey / SecKey. Default: ~/.ydcv")
     parser.add_argument('words',
                         nargs='*',
                         help="words to lookup, or quoted sentences to translate.")
@@ -331,8 +344,16 @@ def arg_parse():
 
 
 def main():
+    global YDAPPID, YDAPPSEC
     options._options = arg_parse()
 
+    if YDAPPID == "" or YDAPPSEC == "":
+        config = configparser.ConfigParser()
+        config.read(os.path.expanduser(options.config))
+        sec = config["YDCV"]
+        YDAPPID = sec["YDAPPID"]
+        YDAPPSEC = sec["YDAPPSEC"]
+
     if options.words:
         for word in options.words:
             lookup_word(word)
